# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/cfdp/cfdp.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/cfdp/cfdp.proto',
  package='yamcs.protobuf.cfdp',
  syntax='proto2',
  serialized_options=_b('\n\022org.yamcs.protobufB\tCfdpProtoP\001'),
  serialized_pb=_b('\n\x1eyamcs/protobuf/cfdp/cfdp.proto\x12\x13yamcs.protobuf.cfdp\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1byamcs/api/annotations.proto\"3\n\nRemoteFile\x12\x10\n\x08\x66ilepath\x18\x01 \x02(\t\x12\x13\n\x0bisDirectory\x18\x02 \x02(\x08\"\xb8\x02\n\x0cTransferInfo\x12\x15\n\rtransactionId\x18\x01 \x01(\x04\x12-\n\tstartTime\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\x05state\x18\x03 \x01(\x0e\x32\".yamcs.protobuf.cfdp.TransferState\x12\x0e\n\x06\x62ucket\x18\x04 \x01(\t\x12\x12\n\nobjectName\x18\x05 \x01(\t\x12\x12\n\nremotePath\x18\x06 \x01(\t\x12\x39\n\tdirection\x18\x07 \x01(\x0e\x32&.yamcs.protobuf.cfdp.TransferDirection\x12\x11\n\ttotalSize\x18\x08 \x01(\x04\x12\x17\n\x0fsizeTransferred\x18\t \x01(\x04\x12\x10\n\x08reliable\x18\n \x01(\x08\"\x9f\x03\n\x15\x43reateTransferRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x39\n\tdirection\x18\x02 \x01(\x0e\x32&.yamcs.protobuf.cfdp.TransferDirection\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\x12\x12\n\nobjectName\x18\x04 \x01(\t\x12\x12\n\nremotePath\x18\x05 \x01(\t\x12S\n\x0f\x64ownloadOptions\x18\x06 \x01(\x0b\x32:.yamcs.protobuf.cfdp.CreateTransferRequest.DownloadOptions\x12O\n\ruploadOptions\x18\x07 \x01(\x0b\x32\x38.yamcs.protobuf.cfdp.CreateTransferRequest.UploadOptions\x1aH\n\rUploadOptions\x12\x11\n\toverwrite\x18\x01 \x01(\x08\x12\x12\n\ncreatePath\x18\x02 \x01(\x08\x12\x10\n\x08reliable\x18\x03 \x01(\x08\x1a\x11\n\x0f\x44ownloadOptions\"F\n\x13\x45\x64itTransferRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x03\x12\x11\n\toperation\x18\x03 \x01(\t\"(\n\x14ListTransfersRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"2\n\x12GetTransferRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x03\"L\n\x15ListTransfersResponse\x12\x33\n\x08transfer\x18\x01 \x03(\x0b\x32!.yamcs.protobuf.cfdp.TransferInfo\"a\n\x17ListRemoteFilesResponse\x12\x12\n\nremotePath\x18\x01 \x02(\t\x12\x32\n\tfilepaths\x18\x02 \x03(\x0b\x32\x1f.yamcs.protobuf.cfdp.RemoteFile*-\n\x11TransferDirection\x12\n\n\x06UPLOAD\x10\x01\x12\x0c\n\x08\x44OWNLOAD\x10\x02*C\n\rTransferState\x12\x0b\n\x07RUNNING\x10\x01\x12\n\n\x06PAUSED\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x12\r\n\tCOMPLETED\x10\x04\x32\xad\x04\n\x07\x43\x66\x64pApi\x12\x8c\x01\n\rListTransfers\x12).yamcs.protobuf.cfdp.ListTransfersRequest\x1a*.yamcs.protobuf.cfdp.ListTransfersResponse\"$\x8a\x92\x03 \n\x1e/api/cfdp/{instance}/transfers\x12\x84\x01\n\x0bGetTransfer\x12\'.yamcs.protobuf.cfdp.GetTransferRequest\x1a!.yamcs.protobuf.cfdp.TransferInfo\")\x8a\x92\x03%\n#/api/cfdp/{instance}/transfers/{id}\x12\x88\x01\n\x0e\x43reateTransfer\x12*.yamcs.protobuf.cfdp.CreateTransferRequest\x1a!.yamcs.protobuf.cfdp.TransferInfo\"\'\x8a\x92\x03#\x1a\x1e/api/cfdp/{instance}/transfers:\x01*\x12\x80\x01\n\x0eUpdateTransfer\x12(.yamcs.protobuf.cfdp.EditTransferRequest\x1a\x16.google.protobuf.Empty\",\x8a\x92\x03(*#/api/cfdp/{instance}/transfers/{id}:\x01*B!\n\x12org.yamcs.protobufB\tCfdpProtoP\x01')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,])

_TRANSFERDIRECTION = _descriptor.EnumDescriptor(
  name='TransferDirection',
  full_name='yamcs.protobuf.cfdp.TransferDirection',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UPLOAD', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOWNLOAD', index=1, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1275,
  serialized_end=1320,
)
_sym_db.RegisterEnumDescriptor(_TRANSFERDIRECTION)

TransferDirection = enum_type_wrapper.EnumTypeWrapper(_TRANSFERDIRECTION)
_TRANSFERSTATE = _descriptor.EnumDescriptor(
  name='TransferState',
  full_name='yamcs.protobuf.cfdp.TransferState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PAUSED', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMPLETED', index=3, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1322,
  serialized_end=1389,
)
_sym_db.RegisterEnumDescriptor(_TRANSFERSTATE)

TransferState = enum_type_wrapper.EnumTypeWrapper(_TRANSFERSTATE)
UPLOAD = 1
DOWNLOAD = 2
RUNNING = 1
PAUSED = 2
FAILED = 3
COMPLETED = 4



_REMOTEFILE = _descriptor.Descriptor(
  name='RemoteFile',
  full_name='yamcs.protobuf.cfdp.RemoteFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filepath', full_name='yamcs.protobuf.cfdp.RemoteFile.filepath', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isDirectory', full_name='yamcs.protobuf.cfdp.RemoteFile.isDirectory', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=146,
  serialized_end=197,
)


_TRANSFERINFO = _descriptor.Descriptor(
  name='TransferInfo',
  full_name='yamcs.protobuf.cfdp.TransferInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transactionId', full_name='yamcs.protobuf.cfdp.TransferInfo.transactionId', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='startTime', full_name='yamcs.protobuf.cfdp.TransferInfo.startTime', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.cfdp.TransferInfo.state', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='yamcs.protobuf.cfdp.TransferInfo.bucket', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objectName', full_name='yamcs.protobuf.cfdp.TransferInfo.objectName', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remotePath', full_name='yamcs.protobuf.cfdp.TransferInfo.remotePath', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='direction', full_name='yamcs.protobuf.cfdp.TransferInfo.direction', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='totalSize', full_name='yamcs.protobuf.cfdp.TransferInfo.totalSize', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sizeTransferred', full_name='yamcs.protobuf.cfdp.TransferInfo.sizeTransferred', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reliable', full_name='yamcs.protobuf.cfdp.TransferInfo.reliable', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=200,
  serialized_end=512,
)


_CREATETRANSFERREQUEST_UPLOADOPTIONS = _descriptor.Descriptor(
  name='UploadOptions',
  full_name='yamcs.protobuf.cfdp.CreateTransferRequest.UploadOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='overwrite', full_name='yamcs.protobuf.cfdp.CreateTransferRequest.UploadOptions.overwrite', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='createPath', full_name='yamcs.protobuf.cfdp.CreateTransferRequest.UploadOptions.createPath', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reliable', full_name='yamcs.protobuf.cfdp.CreateTransferRequest.UploadOptions.reliable', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=839,
  serialized_end=911,
)

_CREATETRANSFERREQUEST_DOWNLOADOPTIONS = _descriptor.Descriptor(
  name='DownloadOptions',
  full_name='yamcs.protobuf.cfdp.CreateTransferRequest.DownloadOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=913,
  serialized_end=930,
)

_CREATETRANSFERREQUEST = _descriptor.Descriptor(
  name='CreateTransferRequest',
  full_name='yamcs.protobuf.cfdp.CreateTransferRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.cfdp.CreateTransferRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='direction', full_name='yamcs.protobuf.cfdp.CreateTransferRequest.direction', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='yamcs.protobuf.cfdp.CreateTransferRequest.bucket', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objectName', full_name='yamcs.protobuf.cfdp.CreateTransferRequest.objectName', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remotePath', full_name='yamcs.protobuf.cfdp.CreateTransferRequest.remotePath', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='downloadOptions', full_name='yamcs.protobuf.cfdp.CreateTransferRequest.downloadOptions', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uploadOptions', full_name='yamcs.protobuf.cfdp.CreateTransferRequest.uploadOptions', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CREATETRANSFERREQUEST_UPLOADOPTIONS, _CREATETRANSFERREQUEST_DOWNLOADOPTIONS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=515,
  serialized_end=930,
)


_EDITTRANSFERREQUEST = _descriptor.Descriptor(
  name='EditTransferRequest',
  full_name='yamcs.protobuf.cfdp.EditTransferRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.cfdp.EditTransferRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.cfdp.EditTransferRequest.id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operation', full_name='yamcs.protobuf.cfdp.EditTransferRequest.operation', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=932,
  serialized_end=1002,
)


_LISTTRANSFERSREQUEST = _descriptor.Descriptor(
  name='ListTransfersRequest',
  full_name='yamcs.protobuf.cfdp.ListTransfersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.cfdp.ListTransfersRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1004,
  serialized_end=1044,
)


_GETTRANSFERREQUEST = _descriptor.Descriptor(
  name='GetTransferRequest',
  full_name='yamcs.protobuf.cfdp.GetTransferRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.cfdp.GetTransferRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.cfdp.GetTransferRequest.id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1046,
  serialized_end=1096,
)


_LISTTRANSFERSRESPONSE = _descriptor.Descriptor(
  name='ListTransfersResponse',
  full_name='yamcs.protobuf.cfdp.ListTransfersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transfer', full_name='yamcs.protobuf.cfdp.ListTransfersResponse.transfer', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1098,
  serialized_end=1174,
)


_LISTREMOTEFILESRESPONSE = _descriptor.Descriptor(
  name='ListRemoteFilesResponse',
  full_name='yamcs.protobuf.cfdp.ListRemoteFilesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='remotePath', full_name='yamcs.protobuf.cfdp.ListRemoteFilesResponse.remotePath', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filepaths', full_name='yamcs.protobuf.cfdp.ListRemoteFilesResponse.filepaths', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1176,
  serialized_end=1273,
)

_TRANSFERINFO.fields_by_name['startTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TRANSFERINFO.fields_by_name['state'].enum_type = _TRANSFERSTATE
_TRANSFERINFO.fields_by_name['direction'].enum_type = _TRANSFERDIRECTION
_CREATETRANSFERREQUEST_UPLOADOPTIONS.containing_type = _CREATETRANSFERREQUEST
_CREATETRANSFERREQUEST_DOWNLOADOPTIONS.containing_type = _CREATETRANSFERREQUEST
_CREATETRANSFERREQUEST.fields_by_name['direction'].enum_type = _TRANSFERDIRECTION
_CREATETRANSFERREQUEST.fields_by_name['downloadOptions'].message_type = _CREATETRANSFERREQUEST_DOWNLOADOPTIONS
_CREATETRANSFERREQUEST.fields_by_name['uploadOptions'].message_type = _CREATETRANSFERREQUEST_UPLOADOPTIONS
_LISTTRANSFERSRESPONSE.fields_by_name['transfer'].message_type = _TRANSFERINFO
_LISTREMOTEFILESRESPONSE.fields_by_name['filepaths'].message_type = _REMOTEFILE
DESCRIPTOR.message_types_by_name['RemoteFile'] = _REMOTEFILE
DESCRIPTOR.message_types_by_name['TransferInfo'] = _TRANSFERINFO
DESCRIPTOR.message_types_by_name['CreateTransferRequest'] = _CREATETRANSFERREQUEST
DESCRIPTOR.message_types_by_name['EditTransferRequest'] = _EDITTRANSFERREQUEST
DESCRIPTOR.message_types_by_name['ListTransfersRequest'] = _LISTTRANSFERSREQUEST
DESCRIPTOR.message_types_by_name['GetTransferRequest'] = _GETTRANSFERREQUEST
DESCRIPTOR.message_types_by_name['ListTransfersResponse'] = _LISTTRANSFERSRESPONSE
DESCRIPTOR.message_types_by_name['ListRemoteFilesResponse'] = _LISTREMOTEFILESRESPONSE
DESCRIPTOR.enum_types_by_name['TransferDirection'] = _TRANSFERDIRECTION
DESCRIPTOR.enum_types_by_name['TransferState'] = _TRANSFERSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RemoteFile = _reflection.GeneratedProtocolMessageType('RemoteFile', (_message.Message,), {
  'DESCRIPTOR' : _REMOTEFILE,
  '__module__' : 'yamcs.protobuf.cfdp.cfdp_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.cfdp.RemoteFile)
  })
_sym_db.RegisterMessage(RemoteFile)

TransferInfo = _reflection.GeneratedProtocolMessageType('TransferInfo', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFERINFO,
  '__module__' : 'yamcs.protobuf.cfdp.cfdp_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.cfdp.TransferInfo)
  })
_sym_db.RegisterMessage(TransferInfo)

CreateTransferRequest = _reflection.GeneratedProtocolMessageType('CreateTransferRequest', (_message.Message,), {

  'UploadOptions' : _reflection.GeneratedProtocolMessageType('UploadOptions', (_message.Message,), {
    'DESCRIPTOR' : _CREATETRANSFERREQUEST_UPLOADOPTIONS,
    '__module__' : 'yamcs.protobuf.cfdp.cfdp_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.cfdp.CreateTransferRequest.UploadOptions)
    })
  ,

  'DownloadOptions' : _reflection.GeneratedProtocolMessageType('DownloadOptions', (_message.Message,), {
    'DESCRIPTOR' : _CREATETRANSFERREQUEST_DOWNLOADOPTIONS,
    '__module__' : 'yamcs.protobuf.cfdp.cfdp_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.cfdp.CreateTransferRequest.DownloadOptions)
    })
  ,
  'DESCRIPTOR' : _CREATETRANSFERREQUEST,
  '__module__' : 'yamcs.protobuf.cfdp.cfdp_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.cfdp.CreateTransferRequest)
  })
_sym_db.RegisterMessage(CreateTransferRequest)
_sym_db.RegisterMessage(CreateTransferRequest.UploadOptions)
_sym_db.RegisterMessage(CreateTransferRequest.DownloadOptions)

EditTransferRequest = _reflection.GeneratedProtocolMessageType('EditTransferRequest', (_message.Message,), {
  'DESCRIPTOR' : _EDITTRANSFERREQUEST,
  '__module__' : 'yamcs.protobuf.cfdp.cfdp_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.cfdp.EditTransferRequest)
  })
_sym_db.RegisterMessage(EditTransferRequest)

ListTransfersRequest = _reflection.GeneratedProtocolMessageType('ListTransfersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTTRANSFERSREQUEST,
  '__module__' : 'yamcs.protobuf.cfdp.cfdp_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.cfdp.ListTransfersRequest)
  })
_sym_db.RegisterMessage(ListTransfersRequest)

GetTransferRequest = _reflection.GeneratedProtocolMessageType('GetTransferRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTRANSFERREQUEST,
  '__module__' : 'yamcs.protobuf.cfdp.cfdp_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.cfdp.GetTransferRequest)
  })
_sym_db.RegisterMessage(GetTransferRequest)

ListTransfersResponse = _reflection.GeneratedProtocolMessageType('ListTransfersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTRANSFERSRESPONSE,
  '__module__' : 'yamcs.protobuf.cfdp.cfdp_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.cfdp.ListTransfersResponse)
  })
_sym_db.RegisterMessage(ListTransfersResponse)

ListRemoteFilesResponse = _reflection.GeneratedProtocolMessageType('ListRemoteFilesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTREMOTEFILESRESPONSE,
  '__module__' : 'yamcs.protobuf.cfdp.cfdp_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.cfdp.ListRemoteFilesResponse)
  })
_sym_db.RegisterMessage(ListRemoteFilesResponse)


DESCRIPTOR._options = None

_CFDPAPI = _descriptor.ServiceDescriptor(
  name='CfdpApi',
  full_name='yamcs.protobuf.cfdp.CfdpApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1392,
  serialized_end=1949,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListTransfers',
    full_name='yamcs.protobuf.cfdp.CfdpApi.ListTransfers',
    index=0,
    containing_service=None,
    input_type=_LISTTRANSFERSREQUEST,
    output_type=_LISTTRANSFERSRESPONSE,
    serialized_options=_b('\212\222\003 \n\036/api/cfdp/{instance}/transfers'),
  ),
  _descriptor.MethodDescriptor(
    name='GetTransfer',
    full_name='yamcs.protobuf.cfdp.CfdpApi.GetTransfer',
    index=1,
    containing_service=None,
    input_type=_GETTRANSFERREQUEST,
    output_type=_TRANSFERINFO,
    serialized_options=_b('\212\222\003%\n#/api/cfdp/{instance}/transfers/{id}'),
  ),
  _descriptor.MethodDescriptor(
    name='CreateTransfer',
    full_name='yamcs.protobuf.cfdp.CfdpApi.CreateTransfer',
    index=2,
    containing_service=None,
    input_type=_CREATETRANSFERREQUEST,
    output_type=_TRANSFERINFO,
    serialized_options=_b('\212\222\003#\032\036/api/cfdp/{instance}/transfers:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='UpdateTransfer',
    full_name='yamcs.protobuf.cfdp.CfdpApi.UpdateTransfer',
    index=3,
    containing_service=None,
    input_type=_EDITTRANSFERREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=_b('\212\222\003(*#/api/cfdp/{instance}/transfers/{id}:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_CFDPAPI)

DESCRIPTOR.services_by_name['CfdpApi'] = _CFDPAPI

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/archive/archive.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.protobuf.alarms import alarms_pb2 as yamcs_dot_protobuf_dot_alarms_dot_alarms__pb2
from yamcs.protobuf.pvalue import pvalue_pb2 as yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2
from yamcs.protobuf import yamcs_pb2 as yamcs_dot_protobuf_dot_yamcs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/archive/archive.proto',
  package='yamcs.protobuf.archive',
  syntax='proto2',
  serialized_options=_b('\n\022org.yamcs.protobuf'),
  serialized_pb=_b('\n$yamcs/protobuf/archive/archive.proto\x12\x16yamcs.protobuf.archive\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1byamcs/api/annotations.proto\x1a\"yamcs/protobuf/alarms/alarms.proto\x1a\"yamcs/protobuf/pvalue/pvalue.proto\x1a\x1ayamcs/protobuf/yamcs.proto\"\xc4\x01\n\x1cStreamParameterValuesRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12)\n\x05start\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x03ids\x18\x04 \x03(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x11\n\tnamespace\x18\x05 \x01(\t\"\xe0\x01\n\x11ListEventsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0b\n\x03pos\x18\x02 \x01(\x03\x12\r\n\x05limit\x18\x03 \x01(\x05\x12\r\n\x05order\x18\x04 \x01(\t\x12\x10\n\x08severity\x18\x05 \x01(\t\x12\x0e\n\x06source\x18\x06 \x03(\t\x12\x0c\n\x04next\x18\x07 \x01(\t\x12)\n\x05start\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\t\n\x01q\x18\n \x01(\t\"U\n\x12ListEventsResponse\x12$\n\x05\x65vent\x18\x01 \x03(\x0b\x32\x15.yamcs.protobuf.Event\x12\x19\n\x11\x63ontinuationToken\x18\x02 \x01(\t\"\x8d\x01\n\x12\x43reateEventRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x10\n\x08severity\x18\x04 \x01(\t\x12\x0c\n\x04time\x18\x05 \x01(\t\x12\x0e\n\x06source\x18\x06 \x01(\t\x12\x16\n\x0esequenceNumber\x18\x07 \x01(\x05\"\xa5\x01\n\x11ListAlarmsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0b\n\x03pos\x18\x02 \x01(\x03\x12\r\n\x05limit\x18\x03 \x01(\x05\x12)\n\x05start\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05order\x18\x06 \x01(\t\"E\n\x12ListAlarmsResponse\x12/\n\x05\x61larm\x18\x01 \x03(\x0b\x32 .yamcs.protobuf.alarms.AlarmData\"\xd1\x01\n\x1aListParameterAlarmsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tparameter\x18\x02 \x01(\t\x12\x0b\n\x03pos\x18\x03 \x01(\x03\x12\r\n\x05limit\x18\x04 \x01(\x05\x12)\n\x05start\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05order\x18\x07 \x01(\t\x12\x0e\n\x06\x64\x65tail\x18\x08 \x01(\x08\"+\n\x17ListEventSourcesRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"*\n\x18ListEventSourcesResponse\x12\x0e\n\x06source\x18\x01 \x03(\t\"#\n\x12ParameterGroupInfo\x12\r\n\x05group\x18\x01 \x03(\t\"\xc5\x01\n\x1eListCommandHistoryIndexRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tmergeTime\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\x12)\n\x05start\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04next\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x03(\t\"\xbe\x01\n\x15ListEventIndexRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tmergeTime\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\x12)\n\x05start\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04next\x18\x06 \x01(\t\x12\x0e\n\x06source\x18\x07 \x03(\t\"\xbd\x01\n\x16ListPacketIndexRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tmergeTime\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\x12)\n\x05start\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04next\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x03(\t\"\xc1\x01\n\x19ListParameterIndexRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tmergeTime\x18\x02 \x01(\x05\x12\r\n\x05limit\x18\x03 \x01(\x05\x12)\n\x05start\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04next\x18\x06 \x01(\t\x12\r\n\x05group\x18\x07 \x03(\t\"\xa2\x01\n\x1cListCompletenessIndexRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x05\x12)\n\x05start\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04next\x18\x05 \x01(\t\"]\n\rIndexResponse\x12\x31\n\x05group\x18\x01 \x03(\x0b\x32\".yamcs.protobuf.archive.IndexGroup\x12\x19\n\x11\x63ontinuationToken\x18\x02 \x01(\t\"j\n\nIndexGroup\x12)\n\x02id\x18\x01 \x01(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x31\n\x05\x65ntry\x18\x02 \x03(\x0b\x32\".yamcs.protobuf.archive.IndexEntry\"[\n\nIndexEntry\x12\r\n\x05start\x18\x01 \x01(\t\x12\x0c\n\x04stop\x18\x02 \x01(\t\x12\r\n\x05\x63ount\x18\x03 \x01(\x05\x12\x10\n\x08seqStart\x18\x04 \x01(\x03\x12\x0f\n\x07seqStop\x18\x05 \x01(\x03\"*\n\x16ListPacketNamesRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"\'\n\x17ListPacketNamesResponse\x12\x0c\n\x04name\x18\x01 \x03(\t\".\n\x1aListParameterGroupsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"\x86\x02\n\x1bListParameterHistoryRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03pos\x18\x03 \x01(\x03\x12\r\n\x05limit\x18\x04 \x01(\x05\x12\x10\n\x08norepeat\x18\x05 \x01(\x08\x12)\n\x05start\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05order\x18\x08 \x01(\t\x12\x12\n\nnorealtime\x18\t \x01(\x08\x12\x11\n\tprocessor\x18\n \x01(\t\x12\x0e\n\x06source\x18\x0b \x01(\t\"s\n\x1cListParameterHistoryResponse\x12\x38\n\tparameter\x18\x01 \x03(\x0b\x32%.yamcs.protobuf.pvalue.ParameterValue\x12\x19\n\x11\x63ontinuationToken\x18\x02 \x01(\t\"\xc2\x01\n\x12ListPacketsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0b\n\x03pos\x18\x02 \x01(\x03\x12\r\n\x05limit\x18\x03 \x01(\x05\x12\r\n\x05order\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x03(\t\x12\x0c\n\x04next\x18\x06 \x01(\t\x12)\n\x05start\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"^\n\x13ListPacketsResponse\x12,\n\x06packet\x18\x01 \x03(\x0b\x32\x1c.yamcs.protobuf.TmPacketData\x12\x19\n\x11\x63ontinuationToken\x18\x02 \x01(\t\"E\n\x10GetPacketRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0f\n\x07gentime\x18\x02 \x01(\x03\x12\x0e\n\x06seqnum\x18\x03 \x01(\x05\"\xd7\x01\n\x1aGetParameterSamplesRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12)\n\x05start\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05\x63ount\x18\x05 \x01(\x05\x12\x12\n\nnorealtime\x18\x06 \x01(\x08\x12\x11\n\tprocessor\x18\x07 \x01(\t\x12\x0e\n\x06source\x18\x08 \x01(\t2\xaa\x15\n\x10StreamArchiveApi\x12\x89\x01\n\nListEvents\x12).yamcs.protobuf.archive.ListEventsRequest\x1a*.yamcs.protobuf.archive.ListEventsResponse\"$\x8a\x92\x03 \n\x1e/api/archive/{instance}/events\x12y\n\x0b\x43reateEvent\x12*.yamcs.protobuf.archive.CreateEventRequest\x1a\x15.yamcs.protobuf.Event\"\'\x8a\x92\x03#\x1a\x1e/api/archive/{instance}/events:\x01*\x12\xa3\x01\n\x10ListEventSources\x12/.yamcs.protobuf.archive.ListEventSourcesRequest\x1a\x30.yamcs.protobuf.archive.ListEventSourcesResponse\",\x8a\x92\x03(\n&/api/archive/{instance}/events/sources\x12\x89\x01\n\nListAlarms\x12).yamcs.protobuf.archive.ListAlarmsRequest\x1a*.yamcs.protobuf.archive.ListAlarmsResponse\"$\x8a\x92\x03 \n\x1e/api/archive/{instance}/alarms\x12\xa8\x01\n\x13ListParameterAlarms\x12\x32.yamcs.protobuf.archive.ListParameterAlarmsRequest\x1a*.yamcs.protobuf.archive.ListAlarmsResponse\"1\x8a\x92\x03-\n+/api/archive/{instance}/alarms/{parameter*}\x12\xa5\x01\n\x13ListParameterGroups\x12\x32.yamcs.protobuf.archive.ListParameterGroupsRequest\x1a*.yamcs.protobuf.archive.ParameterGroupInfo\".\x8a\x92\x03*\n(/api/archive/{instance}/parameter-groups\x12\xba\x01\n\x14ListParameterHistory\x12\x33.yamcs.protobuf.archive.ListParameterHistoryRequest\x1a\x34.yamcs.protobuf.archive.ListParameterHistoryResponse\"7\x8a\x92\x03\x33\n1/api/stream-archive/{instance}/parameters/{name*}\x12\xb4\x01\n\x15StreamParameterValues\x12\x34.yamcs.protobuf.archive.StreamParameterValuesRequest\x1a$.yamcs.protobuf.pvalue.ParameterData\"=\x8a\x92\x03\x39\x1a\x34/api/stream-archive/{instance}:streamParameterValues:\x01*0\x01\x12\xad\x01\n\x13GetParameterSamples\x12\x32.yamcs.protobuf.archive.GetParameterSamplesRequest\x1a!.yamcs.protobuf.pvalue.TimeSeries\"?\x8a\x92\x03;\n9/api/stream-archive/{instance}/parameters/{name*}/samples\x12\xa5\x01\n\x17ListCommandHistoryIndex\x12\x36.yamcs.protobuf.archive.ListCommandHistoryIndexRequest\x1a%.yamcs.protobuf.archive.IndexResponse\"+\x8a\x92\x03\'\n%/api/archive/{instance}/command-index\x12\x91\x01\n\x0eListEventIndex\x12-.yamcs.protobuf.archive.ListEventIndexRequest\x1a%.yamcs.protobuf.archive.IndexResponse\")\x8a\x92\x03%\n#/api/archive/{instance}/event-index\x12\x94\x01\n\x0fListPacketIndex\x12..yamcs.protobuf.archive.ListPacketIndexRequest\x1a%.yamcs.protobuf.archive.IndexResponse\"*\x8a\x92\x03&\n$/api/archive/{instance}/packet-index\x12\x9d\x01\n\x12ListParameterIndex\x12\x31.yamcs.protobuf.archive.ListParameterIndexRequest\x1a%.yamcs.protobuf.archive.IndexResponse\"-\x8a\x92\x03)\n\'/api/archive/{instance}/parameter-index\x12\xa6\x01\n\x15ListCompletenessIndex\x12\x34.yamcs.protobuf.archive.ListCompletenessIndexRequest\x1a%.yamcs.protobuf.archive.IndexResponse\"0\x8a\x92\x03,\n*/api/archive/{instance}/completeness-index\x12\x9e\x01\n\x0fListPacketNames\x12..yamcs.protobuf.archive.ListPacketNamesRequest\x1a/.yamcs.protobuf.archive.ListPacketNamesResponse\"*\x8a\x92\x03&\n$/api/archive/{instance}/packet-names\x12\x98\x01\n\x0bListPackets\x12*.yamcs.protobuf.archive.ListPacketsRequest\x1a+.yamcs.protobuf.archive.ListPacketsResponse\"0\x8a\x92\x03,\n*/api/archive/{instance}/packets/{gentime?}\x12\x8d\x01\n\tGetPacket\x12(.yamcs.protobuf.archive.GetPacketRequest\x1a\x1c.yamcs.protobuf.TmPacketData\"8\x8a\x92\x03\x34\n2/api/archive/{instance}/packets/{gentime}/{seqnum}B\x14\n\x12org.yamcs.protobuf')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_alarms_dot_alarms__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_yamcs__pb2.DESCRIPTOR,])




_STREAMPARAMETERVALUESREQUEST = _descriptor.Descriptor(
  name='StreamParameterValuesRequest',
  full_name='yamcs.protobuf.archive.StreamParameterValuesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.StreamParameterValuesRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.StreamParameterValuesRequest.start', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.StreamParameterValuesRequest.stop', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ids', full_name='yamcs.protobuf.archive.StreamParameterValuesRequest.ids', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='yamcs.protobuf.archive.StreamParameterValuesRequest.namespace', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=227,
  serialized_end=423,
)


_LISTEVENTSREQUEST = _descriptor.Descriptor(
  name='ListEventsRequest',
  full_name='yamcs.protobuf.archive.ListEventsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.ListEventsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pos', full_name='yamcs.protobuf.archive.ListEventsRequest.pos', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.archive.ListEventsRequest.limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order', full_name='yamcs.protobuf.archive.ListEventsRequest.order', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='severity', full_name='yamcs.protobuf.archive.ListEventsRequest.severity', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.archive.ListEventsRequest.source', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next', full_name='yamcs.protobuf.archive.ListEventsRequest.next', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.ListEventsRequest.start', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.ListEventsRequest.stop', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='q', full_name='yamcs.protobuf.archive.ListEventsRequest.q', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=426,
  serialized_end=650,
)


_LISTEVENTSRESPONSE = _descriptor.Descriptor(
  name='ListEventsResponse',
  full_name='yamcs.protobuf.archive.ListEventsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event', full_name='yamcs.protobuf.archive.ListEventsResponse.event', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuationToken', full_name='yamcs.protobuf.archive.ListEventsResponse.continuationToken', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=652,
  serialized_end=737,
)


_CREATEEVENTREQUEST = _descriptor.Descriptor(
  name='CreateEventRequest',
  full_name='yamcs.protobuf.archive.CreateEventRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.CreateEventRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.archive.CreateEventRequest.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message', full_name='yamcs.protobuf.archive.CreateEventRequest.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='severity', full_name='yamcs.protobuf.archive.CreateEventRequest.severity', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time', full_name='yamcs.protobuf.archive.CreateEventRequest.time', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.archive.CreateEventRequest.source', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequenceNumber', full_name='yamcs.protobuf.archive.CreateEventRequest.sequenceNumber', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=740,
  serialized_end=881,
)


_LISTALARMSREQUEST = _descriptor.Descriptor(
  name='ListAlarmsRequest',
  full_name='yamcs.protobuf.archive.ListAlarmsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.ListAlarmsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pos', full_name='yamcs.protobuf.archive.ListAlarmsRequest.pos', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.archive.ListAlarmsRequest.limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.ListAlarmsRequest.start', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.ListAlarmsRequest.stop', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order', full_name='yamcs.protobuf.archive.ListAlarmsRequest.order', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=884,
  serialized_end=1049,
)


_LISTALARMSRESPONSE = _descriptor.Descriptor(
  name='ListAlarmsResponse',
  full_name='yamcs.protobuf.archive.ListAlarmsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='alarm', full_name='yamcs.protobuf.archive.ListAlarmsResponse.alarm', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1051,
  serialized_end=1120,
)


_LISTPARAMETERALARMSREQUEST = _descriptor.Descriptor(
  name='ListParameterAlarmsRequest',
  full_name='yamcs.protobuf.archive.ListParameterAlarmsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.ListParameterAlarmsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameter', full_name='yamcs.protobuf.archive.ListParameterAlarmsRequest.parameter', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pos', full_name='yamcs.protobuf.archive.ListParameterAlarmsRequest.pos', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.archive.ListParameterAlarmsRequest.limit', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.ListParameterAlarmsRequest.start', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.ListParameterAlarmsRequest.stop', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order', full_name='yamcs.protobuf.archive.ListParameterAlarmsRequest.order', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='detail', full_name='yamcs.protobuf.archive.ListParameterAlarmsRequest.detail', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1123,
  serialized_end=1332,
)


_LISTEVENTSOURCESREQUEST = _descriptor.Descriptor(
  name='ListEventSourcesRequest',
  full_name='yamcs.protobuf.archive.ListEventSourcesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.ListEventSourcesRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1334,
  serialized_end=1377,
)


_LISTEVENTSOURCESRESPONSE = _descriptor.Descriptor(
  name='ListEventSourcesResponse',
  full_name='yamcs.protobuf.archive.ListEventSourcesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.archive.ListEventSourcesResponse.source', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1379,
  serialized_end=1421,
)


_PARAMETERGROUPINFO = _descriptor.Descriptor(
  name='ParameterGroupInfo',
  full_name='yamcs.protobuf.archive.ParameterGroupInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group', full_name='yamcs.protobuf.archive.ParameterGroupInfo.group', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1423,
  serialized_end=1458,
)


_LISTCOMMANDHISTORYINDEXREQUEST = _descriptor.Descriptor(
  name='ListCommandHistoryIndexRequest',
  full_name='yamcs.protobuf.archive.ListCommandHistoryIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.ListCommandHistoryIndexRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mergeTime', full_name='yamcs.protobuf.archive.ListCommandHistoryIndexRequest.mergeTime', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.archive.ListCommandHistoryIndexRequest.limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.ListCommandHistoryIndexRequest.start', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.ListCommandHistoryIndexRequest.stop', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next', full_name='yamcs.protobuf.archive.ListCommandHistoryIndexRequest.next', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.archive.ListCommandHistoryIndexRequest.name', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1461,
  serialized_end=1658,
)


_LISTEVENTINDEXREQUEST = _descriptor.Descriptor(
  name='ListEventIndexRequest',
  full_name='yamcs.protobuf.archive.ListEventIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.ListEventIndexRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mergeTime', full_name='yamcs.protobuf.archive.ListEventIndexRequest.mergeTime', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.archive.ListEventIndexRequest.limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.ListEventIndexRequest.start', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.ListEventIndexRequest.stop', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next', full_name='yamcs.protobuf.archive.ListEventIndexRequest.next', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.archive.ListEventIndexRequest.source', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1661,
  serialized_end=1851,
)


_LISTPACKETINDEXREQUEST = _descriptor.Descriptor(
  name='ListPacketIndexRequest',
  full_name='yamcs.protobuf.archive.ListPacketIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.ListPacketIndexRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mergeTime', full_name='yamcs.protobuf.archive.ListPacketIndexRequest.mergeTime', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.archive.ListPacketIndexRequest.limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.ListPacketIndexRequest.start', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.ListPacketIndexRequest.stop', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next', full_name='yamcs.protobuf.archive.ListPacketIndexRequest.next', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.archive.ListPacketIndexRequest.name', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1854,
  serialized_end=2043,
)


_LISTPARAMETERINDEXREQUEST = _descriptor.Descriptor(
  name='ListParameterIndexRequest',
  full_name='yamcs.protobuf.archive.ListParameterIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.ListParameterIndexRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mergeTime', full_name='yamcs.protobuf.archive.ListParameterIndexRequest.mergeTime', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.archive.ListParameterIndexRequest.limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.ListParameterIndexRequest.start', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.ListParameterIndexRequest.stop', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next', full_name='yamcs.protobuf.archive.ListParameterIndexRequest.next', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group', full_name='yamcs.protobuf.archive.ListParameterIndexRequest.group', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2046,
  serialized_end=2239,
)


_LISTCOMPLETENESSINDEXREQUEST = _descriptor.Descriptor(
  name='ListCompletenessIndexRequest',
  full_name='yamcs.protobuf.archive.ListCompletenessIndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.ListCompletenessIndexRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.archive.ListCompletenessIndexRequest.limit', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.ListCompletenessIndexRequest.start', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.ListCompletenessIndexRequest.stop', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next', full_name='yamcs.protobuf.archive.ListCompletenessIndexRequest.next', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2242,
  serialized_end=2404,
)


_INDEXRESPONSE = _descriptor.Descriptor(
  name='IndexResponse',
  full_name='yamcs.protobuf.archive.IndexResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='group', full_name='yamcs.protobuf.archive.IndexResponse.group', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuationToken', full_name='yamcs.protobuf.archive.IndexResponse.continuationToken', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2406,
  serialized_end=2499,
)


_INDEXGROUP = _descriptor.Descriptor(
  name='IndexGroup',
  full_name='yamcs.protobuf.archive.IndexGroup',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.archive.IndexGroup.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entry', full_name='yamcs.protobuf.archive.IndexGroup.entry', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2501,
  serialized_end=2607,
)


_INDEXENTRY = _descriptor.Descriptor(
  name='IndexEntry',
  full_name='yamcs.protobuf.archive.IndexEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.IndexEntry.start', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.IndexEntry.stop', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='yamcs.protobuf.archive.IndexEntry.count', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seqStart', full_name='yamcs.protobuf.archive.IndexEntry.seqStart', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seqStop', full_name='yamcs.protobuf.archive.IndexEntry.seqStop', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2609,
  serialized_end=2700,
)


_LISTPACKETNAMESREQUEST = _descriptor.Descriptor(
  name='ListPacketNamesRequest',
  full_name='yamcs.protobuf.archive.ListPacketNamesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.ListPacketNamesRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2702,
  serialized_end=2744,
)


_LISTPACKETNAMESRESPONSE = _descriptor.Descriptor(
  name='ListPacketNamesResponse',
  full_name='yamcs.protobuf.archive.ListPacketNamesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.archive.ListPacketNamesResponse.name', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2746,
  serialized_end=2785,
)


_LISTPARAMETERGROUPSREQUEST = _descriptor.Descriptor(
  name='ListParameterGroupsRequest',
  full_name='yamcs.protobuf.archive.ListParameterGroupsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.ListParameterGroupsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2787,
  serialized_end=2833,
)


_LISTPARAMETERHISTORYREQUEST = _descriptor.Descriptor(
  name='ListParameterHistoryRequest',
  full_name='yamcs.protobuf.archive.ListParameterHistoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.ListParameterHistoryRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.archive.ListParameterHistoryRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pos', full_name='yamcs.protobuf.archive.ListParameterHistoryRequest.pos', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.archive.ListParameterHistoryRequest.limit', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='norepeat', full_name='yamcs.protobuf.archive.ListParameterHistoryRequest.norepeat', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.ListParameterHistoryRequest.start', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.ListParameterHistoryRequest.stop', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order', full_name='yamcs.protobuf.archive.ListParameterHistoryRequest.order', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='norealtime', full_name='yamcs.protobuf.archive.ListParameterHistoryRequest.norealtime', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.archive.ListParameterHistoryRequest.processor', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.archive.ListParameterHistoryRequest.source', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2836,
  serialized_end=3098,
)


_LISTPARAMETERHISTORYRESPONSE = _descriptor.Descriptor(
  name='ListParameterHistoryResponse',
  full_name='yamcs.protobuf.archive.ListParameterHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parameter', full_name='yamcs.protobuf.archive.ListParameterHistoryResponse.parameter', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuationToken', full_name='yamcs.protobuf.archive.ListParameterHistoryResponse.continuationToken', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3100,
  serialized_end=3215,
)


_LISTPACKETSREQUEST = _descriptor.Descriptor(
  name='ListPacketsRequest',
  full_name='yamcs.protobuf.archive.ListPacketsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.ListPacketsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pos', full_name='yamcs.protobuf.archive.ListPacketsRequest.pos', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.archive.ListPacketsRequest.limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order', full_name='yamcs.protobuf.archive.ListPacketsRequest.order', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.archive.ListPacketsRequest.name', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='next', full_name='yamcs.protobuf.archive.ListPacketsRequest.next', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.ListPacketsRequest.start', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.ListPacketsRequest.stop', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3218,
  serialized_end=3412,
)


_LISTPACKETSRESPONSE = _descriptor.Descriptor(
  name='ListPacketsResponse',
  full_name='yamcs.protobuf.archive.ListPacketsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='packet', full_name='yamcs.protobuf.archive.ListPacketsResponse.packet', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='continuationToken', full_name='yamcs.protobuf.archive.ListPacketsResponse.continuationToken', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3414,
  serialized_end=3508,
)


_GETPACKETREQUEST = _descriptor.Descriptor(
  name='GetPacketRequest',
  full_name='yamcs.protobuf.archive.GetPacketRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.GetPacketRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gentime', full_name='yamcs.protobuf.archive.GetPacketRequest.gentime', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seqnum', full_name='yamcs.protobuf.archive.GetPacketRequest.seqnum', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3510,
  serialized_end=3579,
)


_GETPARAMETERSAMPLESREQUEST = _descriptor.Descriptor(
  name='GetParameterSamplesRequest',
  full_name='yamcs.protobuf.archive.GetParameterSamplesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.archive.GetParameterSamplesRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.archive.GetParameterSamplesRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.archive.GetParameterSamplesRequest.start', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.archive.GetParameterSamplesRequest.stop', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='yamcs.protobuf.archive.GetParameterSamplesRequest.count', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='norealtime', full_name='yamcs.protobuf.archive.GetParameterSamplesRequest.norealtime', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.archive.GetParameterSamplesRequest.processor', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.archive.GetParameterSamplesRequest.source', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3582,
  serialized_end=3797,
)

_STREAMPARAMETERVALUESREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMPARAMETERVALUESREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STREAMPARAMETERVALUESREQUEST.fields_by_name['ids'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_LISTEVENTSREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTEVENTSREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTEVENTSRESPONSE.fields_by_name['event'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._EVENT
_LISTALARMSREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTALARMSREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTALARMSRESPONSE.fields_by_name['alarm'].message_type = yamcs_dot_protobuf_dot_alarms_dot_alarms__pb2._ALARMDATA
_LISTPARAMETERALARMSREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPARAMETERALARMSREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTCOMMANDHISTORYINDEXREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTCOMMANDHISTORYINDEXREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTEVENTINDEXREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTEVENTINDEXREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPACKETINDEXREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPACKETINDEXREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPARAMETERINDEXREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPARAMETERINDEXREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTCOMPLETENESSINDEXREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTCOMPLETENESSINDEXREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_INDEXRESPONSE.fields_by_name['group'].message_type = _INDEXGROUP
_INDEXGROUP.fields_by_name['id'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_INDEXGROUP.fields_by_name['entry'].message_type = _INDEXENTRY
_LISTPARAMETERHISTORYREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPARAMETERHISTORYREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPARAMETERHISTORYRESPONSE.fields_by_name['parameter'].message_type = yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2._PARAMETERVALUE
_LISTPACKETSREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPACKETSREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LISTPACKETSRESPONSE.fields_by_name['packet'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._TMPACKETDATA
_GETPARAMETERSAMPLESREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_GETPARAMETERSAMPLESREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['StreamParameterValuesRequest'] = _STREAMPARAMETERVALUESREQUEST
DESCRIPTOR.message_types_by_name['ListEventsRequest'] = _LISTEVENTSREQUEST
DESCRIPTOR.message_types_by_name['ListEventsResponse'] = _LISTEVENTSRESPONSE
DESCRIPTOR.message_types_by_name['CreateEventRequest'] = _CREATEEVENTREQUEST
DESCRIPTOR.message_types_by_name['ListAlarmsRequest'] = _LISTALARMSREQUEST
DESCRIPTOR.message_types_by_name['ListAlarmsResponse'] = _LISTALARMSRESPONSE
DESCRIPTOR.message_types_by_name['ListParameterAlarmsRequest'] = _LISTPARAMETERALARMSREQUEST
DESCRIPTOR.message_types_by_name['ListEventSourcesRequest'] = _LISTEVENTSOURCESREQUEST
DESCRIPTOR.message_types_by_name['ListEventSourcesResponse'] = _LISTEVENTSOURCESRESPONSE
DESCRIPTOR.message_types_by_name['ParameterGroupInfo'] = _PARAMETERGROUPINFO
DESCRIPTOR.message_types_by_name['ListCommandHistoryIndexRequest'] = _LISTCOMMANDHISTORYINDEXREQUEST
DESCRIPTOR.message_types_by_name['ListEventIndexRequest'] = _LISTEVENTINDEXREQUEST
DESCRIPTOR.message_types_by_name['ListPacketIndexRequest'] = _LISTPACKETINDEXREQUEST
DESCRIPTOR.message_types_by_name['ListParameterIndexRequest'] = _LISTPARAMETERINDEXREQUEST
DESCRIPTOR.message_types_by_name['ListCompletenessIndexRequest'] = _LISTCOMPLETENESSINDEXREQUEST
DESCRIPTOR.message_types_by_name['IndexResponse'] = _INDEXRESPONSE
DESCRIPTOR.message_types_by_name['IndexGroup'] = _INDEXGROUP
DESCRIPTOR.message_types_by_name['IndexEntry'] = _INDEXENTRY
DESCRIPTOR.message_types_by_name['ListPacketNamesRequest'] = _LISTPACKETNAMESREQUEST
DESCRIPTOR.message_types_by_name['ListPacketNamesResponse'] = _LISTPACKETNAMESRESPONSE
DESCRIPTOR.message_types_by_name['ListParameterGroupsRequest'] = _LISTPARAMETERGROUPSREQUEST
DESCRIPTOR.message_types_by_name['ListParameterHistoryRequest'] = _LISTPARAMETERHISTORYREQUEST
DESCRIPTOR.message_types_by_name['ListParameterHistoryResponse'] = _LISTPARAMETERHISTORYRESPONSE
DESCRIPTOR.message_types_by_name['ListPacketsRequest'] = _LISTPACKETSREQUEST
DESCRIPTOR.message_types_by_name['ListPacketsResponse'] = _LISTPACKETSRESPONSE
DESCRIPTOR.message_types_by_name['GetPacketRequest'] = _GETPACKETREQUEST
DESCRIPTOR.message_types_by_name['GetParameterSamplesRequest'] = _GETPARAMETERSAMPLESREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StreamParameterValuesRequest = _reflection.GeneratedProtocolMessageType('StreamParameterValuesRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMPARAMETERVALUESREQUEST,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.StreamParameterValuesRequest)
  })
_sym_db.RegisterMessage(StreamParameterValuesRequest)

ListEventsRequest = _reflection.GeneratedProtocolMessageType('ListEventsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTEVENTSREQUEST,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListEventsRequest)
  })
_sym_db.RegisterMessage(ListEventsRequest)

ListEventsResponse = _reflection.GeneratedProtocolMessageType('ListEventsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTEVENTSRESPONSE,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListEventsResponse)
  })
_sym_db.RegisterMessage(ListEventsResponse)

CreateEventRequest = _reflection.GeneratedProtocolMessageType('CreateEventRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEEVENTREQUEST,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.CreateEventRequest)
  })
_sym_db.RegisterMessage(CreateEventRequest)

ListAlarmsRequest = _reflection.GeneratedProtocolMessageType('ListAlarmsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTALARMSREQUEST,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListAlarmsRequest)
  })
_sym_db.RegisterMessage(ListAlarmsRequest)

ListAlarmsResponse = _reflection.GeneratedProtocolMessageType('ListAlarmsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTALARMSRESPONSE,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListAlarmsResponse)
  })
_sym_db.RegisterMessage(ListAlarmsResponse)

ListParameterAlarmsRequest = _reflection.GeneratedProtocolMessageType('ListParameterAlarmsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPARAMETERALARMSREQUEST,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListParameterAlarmsRequest)
  })
_sym_db.RegisterMessage(ListParameterAlarmsRequest)

ListEventSourcesRequest = _reflection.GeneratedProtocolMessageType('ListEventSourcesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTEVENTSOURCESREQUEST,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListEventSourcesRequest)
  })
_sym_db.RegisterMessage(ListEventSourcesRequest)

ListEventSourcesResponse = _reflection.GeneratedProtocolMessageType('ListEventSourcesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTEVENTSOURCESRESPONSE,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListEventSourcesResponse)
  })
_sym_db.RegisterMessage(ListEventSourcesResponse)

ParameterGroupInfo = _reflection.GeneratedProtocolMessageType('ParameterGroupInfo', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETERGROUPINFO,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ParameterGroupInfo)
  })
_sym_db.RegisterMessage(ParameterGroupInfo)

ListCommandHistoryIndexRequest = _reflection.GeneratedProtocolMessageType('ListCommandHistoryIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMMANDHISTORYINDEXREQUEST,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListCommandHistoryIndexRequest)
  })
_sym_db.RegisterMessage(ListCommandHistoryIndexRequest)

ListEventIndexRequest = _reflection.GeneratedProtocolMessageType('ListEventIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTEVENTINDEXREQUEST,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListEventIndexRequest)
  })
_sym_db.RegisterMessage(ListEventIndexRequest)

ListPacketIndexRequest = _reflection.GeneratedProtocolMessageType('ListPacketIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPACKETINDEXREQUEST,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListPacketIndexRequest)
  })
_sym_db.RegisterMessage(ListPacketIndexRequest)

ListParameterIndexRequest = _reflection.GeneratedProtocolMessageType('ListParameterIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPARAMETERINDEXREQUEST,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListParameterIndexRequest)
  })
_sym_db.RegisterMessage(ListParameterIndexRequest)

ListCompletenessIndexRequest = _reflection.GeneratedProtocolMessageType('ListCompletenessIndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTCOMPLETENESSINDEXREQUEST,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListCompletenessIndexRequest)
  })
_sym_db.RegisterMessage(ListCompletenessIndexRequest)

IndexResponse = _reflection.GeneratedProtocolMessageType('IndexResponse', (_message.Message,), {
  'DESCRIPTOR' : _INDEXRESPONSE,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.IndexResponse)
  })
_sym_db.RegisterMessage(IndexResponse)

IndexGroup = _reflection.GeneratedProtocolMessageType('IndexGroup', (_message.Message,), {
  'DESCRIPTOR' : _INDEXGROUP,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.IndexGroup)
  })
_sym_db.RegisterMessage(IndexGroup)

IndexEntry = _reflection.GeneratedProtocolMessageType('IndexEntry', (_message.Message,), {
  'DESCRIPTOR' : _INDEXENTRY,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.IndexEntry)
  })
_sym_db.RegisterMessage(IndexEntry)

ListPacketNamesRequest = _reflection.GeneratedProtocolMessageType('ListPacketNamesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPACKETNAMESREQUEST,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListPacketNamesRequest)
  })
_sym_db.RegisterMessage(ListPacketNamesRequest)

ListPacketNamesResponse = _reflection.GeneratedProtocolMessageType('ListPacketNamesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPACKETNAMESRESPONSE,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListPacketNamesResponse)
  })
_sym_db.RegisterMessage(ListPacketNamesResponse)

ListParameterGroupsRequest = _reflection.GeneratedProtocolMessageType('ListParameterGroupsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPARAMETERGROUPSREQUEST,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListParameterGroupsRequest)
  })
_sym_db.RegisterMessage(ListParameterGroupsRequest)

ListParameterHistoryRequest = _reflection.GeneratedProtocolMessageType('ListParameterHistoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPARAMETERHISTORYREQUEST,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListParameterHistoryRequest)
  })
_sym_db.RegisterMessage(ListParameterHistoryRequest)

ListParameterHistoryResponse = _reflection.GeneratedProtocolMessageType('ListParameterHistoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPARAMETERHISTORYRESPONSE,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListParameterHistoryResponse)
  })
_sym_db.RegisterMessage(ListParameterHistoryResponse)

ListPacketsRequest = _reflection.GeneratedProtocolMessageType('ListPacketsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPACKETSREQUEST,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListPacketsRequest)
  })
_sym_db.RegisterMessage(ListPacketsRequest)

ListPacketsResponse = _reflection.GeneratedProtocolMessageType('ListPacketsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPACKETSRESPONSE,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.ListPacketsResponse)
  })
_sym_db.RegisterMessage(ListPacketsResponse)

GetPacketRequest = _reflection.GeneratedProtocolMessageType('GetPacketRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPACKETREQUEST,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.GetPacketRequest)
  })
_sym_db.RegisterMessage(GetPacketRequest)

GetParameterSamplesRequest = _reflection.GeneratedProtocolMessageType('GetParameterSamplesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPARAMETERSAMPLESREQUEST,
  '__module__' : 'yamcs.protobuf.archive.archive_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.archive.GetParameterSamplesRequest)
  })
_sym_db.RegisterMessage(GetParameterSamplesRequest)


DESCRIPTOR._options = None

_STREAMARCHIVEAPI = _descriptor.ServiceDescriptor(
  name='StreamArchiveApi',
  full_name='yamcs.protobuf.archive.StreamArchiveApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=3800,
  serialized_end=6530,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListEvents',
    full_name='yamcs.protobuf.archive.StreamArchiveApi.ListEvents',
    index=0,
    containing_service=None,
    input_type=_LISTEVENTSREQUEST,
    output_type=_LISTEVENTSRESPONSE,
    serialized_options=_b('\212\222\003 \n\036/api/archive/{instance}/events'),
  ),
  _descriptor.MethodDescriptor(
    name='CreateEvent',
    full_name='yamcs.protobuf.archive.StreamArchiveApi.CreateEvent',
    index=1,
    containing_service=None,
    input_type=_CREATEEVENTREQUEST,
    output_type=yamcs_dot_protobuf_dot_yamcs__pb2._EVENT,
    serialized_options=_b('\212\222\003#\032\036/api/archive/{instance}/events:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='ListEventSources',
    full_name='yamcs.protobuf.archive.StreamArchiveApi.ListEventSources',
    index=2,
    containing_service=None,
    input_type=_LISTEVENTSOURCESREQUEST,
    output_type=_LISTEVENTSOURCESRESPONSE,
    serialized_options=_b('\212\222\003(\n&/api/archive/{instance}/events/sources'),
  ),
  _descriptor.MethodDescriptor(
    name='ListAlarms',
    full_name='yamcs.protobuf.archive.StreamArchiveApi.ListAlarms',
    index=3,
    containing_service=None,
    input_type=_LISTALARMSREQUEST,
    output_type=_LISTALARMSRESPONSE,
    serialized_options=_b('\212\222\003 \n\036/api/archive/{instance}/alarms'),
  ),
  _descriptor.MethodDescriptor(
    name='ListParameterAlarms',
    full_name='yamcs.protobuf.archive.StreamArchiveApi.ListParameterAlarms',
    index=4,
    containing_service=None,
    input_type=_LISTPARAMETERALARMSREQUEST,
    output_type=_LISTALARMSRESPONSE,
    serialized_options=_b('\212\222\003-\n+/api/archive/{instance}/alarms/{parameter*}'),
  ),
  _descriptor.MethodDescriptor(
    name='ListParameterGroups',
    full_name='yamcs.protobuf.archive.StreamArchiveApi.ListParameterGroups',
    index=5,
    containing_service=None,
    input_type=_LISTPARAMETERGROUPSREQUEST,
    output_type=_PARAMETERGROUPINFO,
    serialized_options=_b('\212\222\003*\n(/api/archive/{instance}/parameter-groups'),
  ),
  _descriptor.MethodDescriptor(
    name='ListParameterHistory',
    full_name='yamcs.protobuf.archive.StreamArchiveApi.ListParameterHistory',
    index=6,
    containing_service=None,
    input_type=_LISTPARAMETERHISTORYREQUEST,
    output_type=_LISTPARAMETERHISTORYRESPONSE,
    serialized_options=_b('\212\222\0033\n1/api/stream-archive/{instance}/parameters/{name*}'),
  ),
  _descriptor.MethodDescriptor(
    name='StreamParameterValues',
    full_name='yamcs.protobuf.archive.StreamArchiveApi.StreamParameterValues',
    index=7,
    containing_service=None,
    input_type=_STREAMPARAMETERVALUESREQUEST,
    output_type=yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2._PARAMETERDATA,
    serialized_options=_b('\212\222\0039\0324/api/stream-archive/{instance}:streamParameterValues:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='GetParameterSamples',
    full_name='yamcs.protobuf.archive.StreamArchiveApi.GetParameterSamples',
    index=8,
    containing_service=None,
    input_type=_GETPARAMETERSAMPLESREQUEST,
    output_type=yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2._TIMESERIES,
    serialized_options=_b('\212\222\003;\n9/api/stream-archive/{instance}/parameters/{name*}/samples'),
  ),
  _descriptor.MethodDescriptor(
    name='ListCommandHistoryIndex',
    full_name='yamcs.protobuf.archive.StreamArchiveApi.ListCommandHistoryIndex',
    index=9,
    containing_service=None,
    input_type=_LISTCOMMANDHISTORYINDEXREQUEST,
    output_type=_INDEXRESPONSE,
    serialized_options=_b('\212\222\003\'\n%/api/archive/{instance}/command-index'),
  ),
  _descriptor.MethodDescriptor(
    name='ListEventIndex',
    full_name='yamcs.protobuf.archive.StreamArchiveApi.ListEventIndex',
    index=10,
    containing_service=None,
    input_type=_LISTEVENTINDEXREQUEST,
    output_type=_INDEXRESPONSE,
    serialized_options=_b('\212\222\003%\n#/api/archive/{instance}/event-index'),
  ),
  _descriptor.MethodDescriptor(
    name='ListPacketIndex',
    full_name='yamcs.protobuf.archive.StreamArchiveApi.ListPacketIndex',
    index=11,
    containing_service=None,
    input_type=_LISTPACKETINDEXREQUEST,
    output_type=_INDEXRESPONSE,
    serialized_options=_b('\212\222\003&\n$/api/archive/{instance}/packet-index'),
  ),
  _descriptor.MethodDescriptor(
    name='ListParameterIndex',
    full_name='yamcs.protobuf.archive.StreamArchiveApi.ListParameterIndex',
    index=12,
    containing_service=None,
    input_type=_LISTPARAMETERINDEXREQUEST,
    output_type=_INDEXRESPONSE,
    serialized_options=_b('\212\222\003)\n\'/api/archive/{instance}/parameter-index'),
  ),
  _descriptor.MethodDescriptor(
    name='ListCompletenessIndex',
    full_name='yamcs.protobuf.archive.StreamArchiveApi.ListCompletenessIndex',
    index=13,
    containing_service=None,
    input_type=_LISTCOMPLETENESSINDEXREQUEST,
    output_type=_INDEXRESPONSE,
    serialized_options=_b('\212\222\003,\n*/api/archive/{instance}/completeness-index'),
  ),
  _descriptor.MethodDescriptor(
    name='ListPacketNames',
    full_name='yamcs.protobuf.archive.StreamArchiveApi.ListPacketNames',
    index=14,
    containing_service=None,
    input_type=_LISTPACKETNAMESREQUEST,
    output_type=_LISTPACKETNAMESRESPONSE,
    serialized_options=_b('\212\222\003&\n$/api/archive/{instance}/packet-names'),
  ),
  _descriptor.MethodDescriptor(
    name='ListPackets',
    full_name='yamcs.protobuf.archive.StreamArchiveApi.ListPackets',
    index=15,
    containing_service=None,
    input_type=_LISTPACKETSREQUEST,
    output_type=_LISTPACKETSRESPONSE,
    serialized_options=_b('\212\222\003,\n*/api/archive/{instance}/packets/{gentime?}'),
  ),
  _descriptor.MethodDescriptor(
    name='GetPacket',
    full_name='yamcs.protobuf.archive.StreamArchiveApi.GetPacket',
    index=16,
    containing_service=None,
    input_type=_GETPACKETREQUEST,
    output_type=yamcs_dot_protobuf_dot_yamcs__pb2._TMPACKETDATA,
    serialized_options=_b('\212\222\0034\n2/api/archive/{instance}/packets/{gentime}/{seqnum}'),
  ),
])
_sym_db.RegisterServiceDescriptor(_STREAMARCHIVEAPI)

DESCRIPTOR.services_by_name['StreamArchiveApi'] = _STREAMARCHIVEAPI

# @@protoc_insertion_point(module_scope)
